==> ejc-production-api-3.0.0-20220621.021058-172-sources.jar: com/ejianc/business/production/task/vo/ProductionTaskVO.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/6/21
 * @description:
 */
public class ProductionTaskVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Date taskTime; // 生产任务单日期
    private String customerName; // 客户名称
    private String worksiteName; // 工地名称
    private String productName; // 产品名称
    private BigDecimal quantity; // 数量
    private BigDecimal weighNumber; // 过磅数
    private BigDecimal notWeighNumber; // 未过磅数量
    private String unitName; // 机组名称

    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getWeighNumber() {
        return weighNumber;
    }

    public void setWeighNumber(BigDecimal weighNumber) {
        this.weighNumber = weighNumber;
    }

    public BigDecimal getNotWeighNumber() {
        return notWeighNumber;
    }

    public void setNotWeighNumber(BigDecimal notWeighNumber) {
        this.notWeighNumber = notWeighNumber;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
}

==> ejc-production-api-3.0.0-20220706.114239-205-sources.jar: com/ejianc/business/production/task/vo/ProductionTaskVO.java <==
package com.ejianc.business.production.task.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/6/21
 * @description:
 */
public class ProductionTaskVO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date taskTime; // 生产任务单日期
    private String customerName; // 客户名称
    private String worksiteName; // 工地名称
    private String productName; // 产品名称
    private BigDecimal quantity; // 数量
    private String weighNumber; // 过磅数
    private String notWeighNumber; // 未过磅数量
    private String unitName; // 机组名称

    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }

    public String getWeighNumber() {
        return weighNumber;
    }

    public void setWeighNumber(String weighNumber) {
        this.weighNumber = weighNumber;
    }

    public String getNotWeighNumber() {
        return notWeighNumber;
    }

    public void setNotWeighNumber(String notWeighNumber) {
        this.notWeighNumber = notWeighNumber;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
}
